DFUManifestationError

Enum DFUManifestationError 

#[repr(u8)]
pub enum DFUManifestationError { Target = 1, File = 2, NotDone = 9, Firmware = 10, ErrVendor = 11, Unknown = 14, }
Errors that may happen when device enter Manifestation phase

Variants



Target = 1

File is not targeted for use by this device.



File = 2

File is for this device but fails some vendor-specific verification test.



NotDone = 9

Received DFU_DNLOAD with wLength = 0, but device does not think it has all of the data yet.



Firmware = 10

Device’s firmware is corrupt. It cannot return to run-time (non-DFU) operations.



ErrVendor = 11

A vendor-specific error. iString in DFU_GETSTATUS reply will always be 0.



Unknown = 14

Something went wrong, but the device does not know what it was.