DFUMemError

Enum DFUMemError 

#[repr(u8)]
pub enum DFUMemError { Target = 1, File = 2, Write = 3, Erase = 4, CheckErased = 5, Prog = 6, Verify = 7, Unknown = 14, Address = 8, ErrVendor = 11, }
Errors that may happen when working with the memory (reading, erasing, writting). These will be translated to a corresponding error codes in DFU protocol.

Variants



Target = 1

File is not targeted for use by this device.



File = 2

File is for this device but fails some vendor-specific verification test.



Write = 3

Device is unable to write memory.



Erase = 4

Memory erase function failed.



CheckErased = 5

Memory erase check failed.



Prog = 6

Program memory function failed.



Verify = 7

Programmed memory failed verification.



Unknown = 14

Something went wrong, but the device does not know what it was.



Address = 8

Cannot program memory due to received address that is out of range.



ErrVendor = 11

A vendor-specific error. iString in DFU_GETSTATUS reply will always be 0.