DFUClass

Struct DFUClass 

pub struct DFUClass<B: UsbBus, M: DFUMemIO> { /* private fields */ }
DFU protocol USB class implementation for usb-device library.

Implementations

Source

impl<B: UsbBus, M: DFUMemIO> DFUClass<B, M>

pub fn new(alloc: &UsbBusAllocator<B>, mem: M) -> Self

Creates a new DFUClass with the provided UsbBus and DFUMemIO

pub fn release(self) -> M

This function will consume self and return the owned memory argument that was moved in the call to new()

pub fn set_unexpected_reset_state(&mut self)

This function may be called just after DFUClass::new() to set DFU error state to “Device detected unexpected power on reset” instead of the usual dfuIdle.

pub fn set_firmware_corrupted_state(&mut self)

This function may be called just after DFUClass::new() to set DFU error state to “Device’s firmware is corrupt. It cannot return to run-time (non-DFU) operations” instead of the usual dfuIdle.

pub fn get_address_pointer(&self) -> u32

Return current Address Pointer value.