Enum usbd_dfu::DFUManifestationError [−][src]
#[repr(u8)]
pub enum DFUManifestationError {
Target,
File,
NotDone,
Firmware,
ErrVendor,
Unknown,
}Expand description
Errors that may happen when device enter Manifestation phase
Variants
File is not targeted for use by this device.
File is for this device but fails some vendor-specific verification test.
Received DFU_DNLOAD with wLength = 0, but device does not think it has all of the data yet.
Device’s firmware is corrupt. It cannot return to run-time (non-DFU) operations.
A vendor-specific error. iString in DFU_GETSTATUS reply will always be 0.
Something went wrong, but the device does not know what it was.