pub enum DFUManifestationError {
    Target,
    File,
    NotDone,
    Firmware,
    ErrVendor,
    Unknown,
}
Errors that may happen when device enter Manifestation phase

Variants



Target

File is not targeted for use by this device.



File

File is for this device but fails some vendor-specific verification test.



NotDone

Received DFU_DNLOAD with wLength = 0, but device does not think it has all of the data yet.



Firmware

Device’s firmware is corrupt. It cannot return to run-time (non-DFU) operations.



ErrVendor

A vendor-specific error. iString in DFU_GETSTATUS reply will always be 0.



Unknown

Something went wrong, but the device does not know what it was.