Enum usbd_dfu::DFUMemError [−][src]
#[repr(u8)]
pub enum DFUMemError {
Target,
File,
Write,
Erase,
CheckErased,
Prog,
Verify,
Unknown,
Address,
ErrVendor,
}Expand description
Errors that may happen when working with the memory (reading, erasing, writting). These will be translated to a corresponding error codes in DFU protocol.
Variants
File is not targeted for use by this device.
File is for this device but fails some vendor-specific verification test.
Device is unable to write memory.
Memory erase function failed.
Memory erase check failed.
Program memory function failed.
Programmed memory failed verification.
Something went wrong, but the device does not know what it was.
Cannot program memory due to received address that is out of range.
A vendor-specific error. iString in DFU_GETSTATUS reply will always be 0.