Enum usbd_dfu::DFUMemError
source · pub enum DFUMemError {
Target,
File,
Write,
Erase,
CheckErased,
Prog,
Verify,
Unknown,
Address,
ErrVendor,
}Expand description
Errors that may happen when working with the memory (reading, erasing, writting). These will be translated to a corresponding error codes in DFU protocol.
Variants
Target
File is not targeted for use by this device.
File
File is for this device but fails some vendor-specific verification test.
Write
Device is unable to write memory.
Erase
Memory erase function failed.
CheckErased
Memory erase check failed.
Prog
Program memory function failed.
Verify
Programmed memory failed verification.
Unknown
Something went wrong, but the device does not know what it was.
Address
Cannot program memory due to received address that is out of range.
ErrVendor
A vendor-specific error. iString in DFU_GETSTATUS reply will always be 0.