pub struct DFUClass<B: UsbBus, M: DFUMemIO> { /* private fields */ }Expand description
DFU protocol USB class implementation for usb-device library.
Implementations
Sourceimpl<B: UsbBus, M: DFUMemIO> DFUClass<B, M>
impl<B: UsbBus, M: DFUMemIO> DFUClass<B, M>
Sourcepub fn new(alloc: &UsbBusAllocator<B>, mem: M) -> Self
pub fn new(alloc: &UsbBusAllocator<B>, mem: M) -> Self
Creates a new DFUClass with the provided UsbBus and DFUMemIO
Sourcepub fn release(self) -> M
pub fn release(self) -> M
This function will consume self and return the owned memory argument that was moved in the call to new()
Sourcepub fn set_unexpected_reset_state(&mut self)
pub fn set_unexpected_reset_state(&mut self)
This function may be called just after DFUClass::new() to
set DFU error state to “Device detected unexpected power on reset”
instead of the usual dfuIdle.
Sourcepub fn set_firmware_corrupted_state(&mut self)
pub fn set_firmware_corrupted_state(&mut self)
This function may be called just after DFUClass::new() to
set DFU error state to “Device’s firmware is corrupt. It cannot return to run-time (non-DFU) operations”
instead of the usual dfuIdle.
Sourcepub fn get_address_pointer(&self) -> u32
pub fn get_address_pointer(&self) -> u32
Return current Address Pointer value.